<?php
/**
 * Created by JetBrains PhpStorm.
 * User: paulopimenta
 * Date: 22/01/13
 * Time: 13:43
 * To change this template use File | Settings | File Templates.
 */
namespace Planejamento\Logic\Requisicao;

use Geral\Util\Ambiente;
use \Planejamento\Entities\Prevreti;
use \Planejamento\Logic\Requisicao\Exception\RestricoesServico;
use \Setforms2\Runtime\Helper\Procedure;
use \Setforms2\Runtime\Helper\Procedure\Param;

class RequisicaoServico
{
    const REQUISICAO_SERVICO = 'REQUISICAO_POR_SERVICO_PLA';
    const REQUISICAO_ANALITICA = 'REQUISICAO_ANALITICA_SETOR_PLA';

    public static function getMaxNrPrPrevReti($nrorg, $campos){
        return Prevreti::getRepository()->get_maxNrPrPrevReti($nrorg, $campos);
    }

    public static function verificaProduto($nrorg, $campos, $id){
        $produto = Prevreti::getRepository()->get_produtoId($nrorg, $campos, $id);
        if(!empty($produto))
            RestricoesServico::produtoJaExistente();
    }

    public static function validaCamposFiltro($campos){
        if (empty($campos['CDSERVFILI']) === true)
            RestricoesServico::informeServico();
        if (empty($campos['DTPREVRETI']) === true)
            RestricoesServico::informeData();
        if (empty($campos['IDPREVRETI']) === true)
            RestricoesServico::informeProduto();
    }

    public static function calculaRequisicaoServico($nrorg, $cdfilial, $servicos, $dtinicial, $dtfinal,
        $peacrescimo, $cdoperador, $dthrcalcpr, $stdinicial, $stdfinal, $idarredond, $idprodutos){

        $nrconsplan = \Geral\Util\NovoCodigo::geraCodigo($nrorg, 'CONSPLAN'.$cdfilial);

        $procedure = new Procedure(self::REQUISICAO_SERVICO);
        $procedure->addParam(
            new Param (
                'P_CDFILIAL',
                Param::PARAM_INPUT,
                $cdfilial,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_SERVICOS',
                Param::PARAM_INPUT,
                $servicos,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_DTINICIAL',
                Param::PARAM_INPUT,
                $dtinicial,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_DTFINAL',
                Param::PARAM_INPUT,
                $dtfinal,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_PEACRESCIMO',
                Param::PARAM_INPUT,
                $peacrescimo,
                Param::PARAM_TYPE_INT
            )
        );
        $procedure->addParam(
            new Param (
                'P_CDOPERADOR',
                Param::PARAM_INPUT,
                $cdoperador,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_DTHRCALCPR',
                Param::PARAM_INPUT,
                $dthrcalcpr,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_NRCONSPLAN',
                Param::PARAM_INPUT,
                $nrconsplan,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_STDTINICIAL',
                Param::PARAM_INPUT,
                $stdinicial,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_STDTFINAL',
                Param::PARAM_INPUT,
                $stdfinal,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_IDARREDOND',
                Param::PARAM_INPUT,
                $idarredond,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_IDPRODUTOS',
                Param::PARAM_INPUT,
                $idprodutos,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->call();
        return $nrconsplan;
    }

    public static function sql_searchPrato(){
        $cdPrato = tk_get_field_value('CDPRATO');
        $nmPrato = tk_get_field_value('NMPRATO');
        $nrorg = Ambiente::getNrorg();
        $where = "1 = 1";

        if(empty($cdPrato) == false)
        {
            $where .= "AND PRATO.CDPRATO LIKE '".$cdPrato."%'";
        }
        if(empty($nmPrato) == false){
            $where .= "AND lower(PRATO.NMPRATO) LIKE CONCAT(lower('".$nmPrato."'), '%' )";
        }

        $sql = " SELECT PRATO.CDPRATO AS CDPRATO,
                    PRATO.NMPRATO      AS NMPRATO,
                    PRATO.NRORG        AS NRORG,
                    PRATO.CDFILAUXPRAT AS CDFILAUXPRAT
                    FROM PRATO
                    WHERE PRATO.NRORG   = $nrorg AND $where
                    AND WHERE_PLACEHOLDER AND FILTER_PLACEHOLDER";
        return $sql;
    }
    
    
    public static function geraListaPontoEntrega($pontosEntrega){
        
        $stListaPontoEntrega = '_';
        if(is_array($pontosEntrega)){
            foreach ($pontosEntrega as $pontoEntrega)
                $stListaPontoEntrega .= $pontoEntrega['clipent'].'_';
        } else
            return $pontosEntrega;
        
        return $stListaPontoEntrega;
        
    }

    public static function calculaRequisicaoAnalitica($cdfilial, $servicos, $dtinicial, $dtfinal, $idarquivo,
        $idprodutos, $idsepprato, $peacrescimo, $idarredond, $nrconsplan, $cdprodutoini, $cdprodutofin,
        $cdoperador, $dthrcalcpr, $stdtinicial, $stdtfinal){

        //$nrconsplan = \Geral\Util\Novocodigo::geraCodigo($nrorg, 'CONSPLAN'.$cdfilial);

        $procedure = new Procedure(self::REQUISICAO_ANALITICA);
        $procedure->addParam(
            new Param (
                'P_CDFILIAL',
                Param::PARAM_INPUT,
                $cdfilial,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_SERVICOS',
                Param::PARAM_INPUT,
                $servicos,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_DTINICIAL',
                Param::PARAM_INPUT,
                $dtinicial,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_DTFINAL',
                Param::PARAM_INPUT,
                $dtfinal,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_IDARQUIVO',
                Param::PARAM_INPUT,
                $idarquivo,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_IDPRODUTOS',
                Param::PARAM_INPUT,
                $idprodutos,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_IDSEPPRATO',
                Param::PARAM_INPUT,
                $idsepprato,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_PEACRESCIMO',
                Param::PARAM_INPUT,
                $peacrescimo,
                Param::PARAM_TYPE_INT
            )
        );
        $procedure->addParam(
            new Param (
                'P_IDARREDOND',
                Param::PARAM_INPUT,
                $idarredond,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_NRCONSPLAN',
                Param::PARAM_INPUT,
                $nrconsplan,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_CDPRODUTOINI',
                Param::PARAM_INPUT,
                $cdprodutoini,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_CDPRODUTOFIN',
                Param::PARAM_INPUT,
                $cdprodutofin,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_CDOPERADOR',
                Param::PARAM_INPUT,
                $cdoperador,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_DTHRCALCPR',
                Param::PARAM_INPUT,
                $dthrcalcpr,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_STDTINICIAL',
                Param::PARAM_INPUT,
                $stdtinicial,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->addParam(
            new Param (
                'P_STDTFINAL',
                Param::PARAM_INPUT,
                $stdtfinal,
                Param::PARAM_TYPE_STR
            )
        );
        $procedure->call();
    }
    
    public static function deleteConsPlanAnalitica($nrconsplan)
    {
        $conn = \Setforms2\Shared\Connection::getInstance();
        $SQL =  "DELETE FROM CONSPLAN WHERE NRCONSPLAN= ?";
        $conn->execute($SQL, array($nrconsplan));

    }
    
    
    public static function validaRequisicao($filial, $servico, $dataIni, $dataFin, $tpConsumo, $nrorg){
    	$previsao = Prevreti::getObjectByWhere(
        	"CDFILIAL = ? AND (INSTR(?, CDSERVFILI) <> 0 OR ? = 'T') AND DTPREVRETI BETWEEN ? AND ? AND 
    		 NRREQUEXTR = ? AND INSTR(?, IDPREVRETI) <> 0 AND NRORG = ?",
    		array($filial, $servico, $servico, $dataIni, $dataFin, '0000000000', $tpConsumo, $nrorg)
    	);
    	
    	if ($previsao instanceof Prevreti) {
    		return true;
    	} else {
    		return false;
    	}
    }
}
